The S4 class WaterLevelDataFrame is inherited from
the S3 class data.frame and stores 1d water level
information together with the official stationing along the German federal
waterways Elbe and Rhine.
.Datacontains the data.frame with at least three
columns: station, station_int and w. The columns
station and station_int represent the official stationing
along the waterways in two different formats. They are totally exchangeable
since station <- as.numeric(station_int / 1000)
and station_int <- as.integer(station * 1000).
The column w represents the height of the water level relative to
standard elevation zero (DHHN92). These first three columns are required, but
further columns can be added.
riveris a required slot clearly determining the location of a station.
Possible values of river have to be type character, have to
have a length of one and are either Elbe or Rhine.
timeis a slot determining the time for which the water level has been
computed. time has to be type c("POSIXct",
"POSIXt"), has to have a length of one and be in the range between
1960-01-01 00:00:00 CET and now (Sys.time()) or NA.
gauging_stationspossibly contains a data.frame
with relevant information about gauging stations within the relevant
river stretch and the closer surrounding up- and downstream of the
relevant river stretch. It is usually filled by the functions
waterLevel or waterLevelPegelonline.
gauging_stations_missingpossibly contains a vector of type
character with names of gauging stations for which no gauging data
existed for the requested time. It is automatically filled by the
functions waterLevel, waterLevelPegelonline,
waterLevelFlys3 and waterLevelFlys3Seq.
commentcontains information on which function has been used to create
(WaterLevelDataFrame) or compute (waterLevel,
waterLevelPegelonline, waterLevelFlys3 and
waterLevelFlys3Seq) an object of class
WaterLevelDataFrame.
In addition to the 1d water level data stored in the
data.frame further slots contain necessary information
used for or computed during the computation of water levels: