This dataset contains the 30 stationary 1d water levels for the rivers Elbe and Rhine originally stored in the FLYS3-database.
For both rivers 30 stationary water levels have been computed by means of the 1d hydraulic model SOBEK. The water levels cover the full length of the free flowing river sections with a spatial resolution of 200 m river stretch along the official river stationing. They range from extremely low to extremely high flow conditions and are usually separated vertically by 0.2 - 0.6 m.

df.flysA data.frame with 169980 rows and 4 variables:
name of the relevant water body (type character).
of the FLYS 3 water level (type character). See details for more information.
rivers stationing (type numeric).
water level (cm above gauge zero, type numeric).
The nameing of the water levels is river-specific:
Elbe:
'0.5MNQ', 'MNQ', '0.5MQ', 'a', '0.75MQ', 'b', 'MQ', 'c', '2MQ', '3MQ', 'd', 'e', 'MHQ', 'HQ2', 'f', 'HQ5', 'g', 'h', 'HQ10', 'HQ15', 'HQ20', 'HQ25', 'HQ50', 'HQ75', 'HQ100', 'i', 'HQ150', 'HQ200', 'HQ300', 'HQ500'
Rhine:
'Ud=1', 'Ud=5', 'GlQ2012', 'Ud=50', 'Ud=80', 'Ud=100', 'Ud=120', 'Ud=183', 'MQ', 'Ud=240', 'Ud=270', 'Ud=310', 'Ud=340', 'Ud=356', 'Ud=360', 'MHQ', 'HQ2', 'HQ5', 'HQ5-10', 'HQ10', 'HQ10-20', '~HQ20', 'HQ20-50', 'HQ50', 'HQ50-100', 'HQ100', 'HQ100-200', 'HQ200', 'HQ200-ex', 'HQextr.'
Both lists of water levels are ordered from low to high water levels.
busch_einheitliche_2009hyd1d
hkv_hydrokontor_erstellung_2014hyd1d
bundesanstalt_fur_gewasserkunde_flys_2013hyd1d
bundesanstalt_fur_gewasserkunde_flys_2016hyd1d
deltares_sobek_2018hyd1d