This dataset contains all daily-averaged gauging data
for the gauging stations along Elbe and Rhine operated by
the waterway and shipping administration (Wasserstraßen- und
Schifffahrtsverwaltung (WSV)) since 1960-01-01. Data from
1960-01-01 until 2022-12-31 are validated and were queried from the
BfG-Wiski
(HyDaBa)
and supplied by Datenstelle-M1@bafg.de. Data after 2021-12-31 are
continuously collected from https://pegelonline.wsv.de/gast/start and
are not officially validated. Unvalidated recent data will be replaced
anually and distributed through package and/or internal dataset updates.
The latest version is stored locally under
paste0(options()$hyd1d.datadir, "/df.gauging_data_latest.RDS"). To
modify the location of your locally stored gauging data set using
options() prior to loading the package, e.g.
options("hyd1d.datadir" = "~/.hyd1d");library(hyd1d). The location
can be determined through the environmental variable hyd1d_datadir.