Learn R Programming

hyd1d (version 0.4.6)

getGaugingStations: Extract a WaterLevelDataFrame's slot gauging_stations

Description

A function to extract the slot gauging_stations from an object of class WaterLevelDataFrame.

Usage

getGaugingStations(x)

# S4 method for WaterLevelDataFrame getGaugingStations(x)

Value

The function above extracts the slot gauging_stations and returns an object of class data.frame, which might contain gauging station data that have been used for the interpolation of a water level for the specified date.

Arguments

x

an object of class WaterLevelDataFrame.

See Also

setGaugingStations<--method

Examples

Run this code
wldf <- WaterLevelDataFrame(river   = "Elbe",
                            time    = as.POSIXct("2016-12-21"),
                            station = seq(257, 262, 0.1))
wldf <- waterLevel(wldf)
getGaugingStations(wldf)

Run the code above in your browser using DataLab