Learn R Programming

hyd1d (version 0.4.6)

getGaugingStationsMissing: Extract a WaterLevelDataFrame's slot gauging_stations_missing

Description

A function to extract the slot gauging_stations_missing from an object of class WaterLevelDataFrame.

Usage

getGaugingStationsMissing(x)

# S4 method for WaterLevelDataFrame getGaugingStationsMissing(x)

Value

The function above extracts the slot gauging_stations_missing

and returns an object of class character, which might contain a vector with gauging stations without gauging data for the specified date.

Arguments

x

an object of class WaterLevelDataFrame.

See Also

setGaugingStationsMissing<--method

Examples

Run this code
wldf <- WaterLevelDataFrame(river   = "Elbe",
                            time    = as.POSIXct("1991-12-16"),
                            station = seq(500, 501, 0.1))
wldf <- waterLevel(wldf)
getGaugingStationsMissing(wldf)

Run the code above in your browser using DataLab