Learn R Programming

hyd1d (version 0.4.6)

getTime: Extract a WaterLevelDataFrame's slot time

Description

A function to extract the slot time from an object of class WaterLevelDataFrame.

Usage

getTime(x)

# S4 method for WaterLevelDataFrame getTime(x)

Value

The function above extracts the slot time and returns an object of type c("POSIXct", "POSIXt").

Arguments

x

an object of class WaterLevelDataFrame.

See Also

setTime<--method

Examples

Run this code
wldf <- WaterLevelDataFrame(river   = "Elbe",
                            time    = as.POSIXct("2016-12-21"),
                            station = seq(257, 262, 0.1))
getTime(wldf)

Run the code above in your browser using DataLab