Learn R Programming

hyd1d (version 0.4.6)

plotShiny: Plot a WaterLevelDataFrame in Shiny

Description

This convenience function enables the easy visualisation of interpolated water levels stored as WaterLevelDataFrame using the R package shiny. The results of functions like waterLevel and waterLevelPegelonline can be plotted interactively so that the computation process itself becomes visible.

Usage

plotShiny(
  wldf,
  add_flys = TRUE,
  add_flys_labels = TRUE,
  add_weighting = TRUE,
  ...
)

Value

A plot of a WaterLevelDataFrame.

Arguments

wldf

an object of class WaterLevelDataFrame.

add_flys

logical determining whether the used FLYS3 water levels should be plotted.

add_flys_labels

logical determining whether the used FLYS3 water levels should be labelled.

add_weighting

logical determining whether the weighting of gauging data at the gauging stations should be labelled.

...

further graphical parameters passed to plot.default.

References

bundesanstalt_fur_gewasserkunde_flys_2016hyd1d

Examples

Run this code
wldf <- WaterLevelDataFrame(river   = "Elbe",
                            time    = as.POSIXct("2016-12-21"),
                            station = seq(257, 262, 0.1))
wldf <- waterLevel(wldf, shiny = TRUE)
plotShiny(wldf, TRUE, TRUE, TRUE)

Run the code above in your browser using DataLab