Learn R Programming

hyd1d (version 0.4.6)

updateGaugingData: Update local copy of df.gauging data

Description

Function to overwrite and update the internal dataset df.gauging_data. This function is usually called during the initial loading of the package. If an update of df.gauging_data took place more than 8 days ago, an updated version of df.gauging_data will be downloaded and used.

Usage

updateGaugingData(x)

Value

invisible(logical) notifying whether an updated version of

df.gauging_data has been downloaded.

Arguments

x

path to the file containing df.gauging_data (type character).

Examples

Run this code
  options("hyd1d.datadir" = tempdir())
  updateGaugingData(paste0(options()$hyd1d.datadir,
                           "/df.gauging_data_latest.RDS"))

Run the code above in your browser using DataLab