Function to interpolate
FLYS3
water levels for selected stations and return it with the structure of
df.flys.
waterLevelFlys3InterpolateX(
river = c("Elbe", "Rhine"),
station = NULL,
station_int = NULL
)An object of class data.frame with the structure of
df.flys.
a required argument to fill the WaterLevelDataFrame-slot
river. It has to be type character, has to have a length of
one and can be either Elbe or Rhine.
an optional argument to hand over the stationing along the
specified river. If specified, it has to be type numeric
and has to have the same length as other optional arguments (id,
station_int and w) forming the data.frame-component
of a WaterLevelDataFrame. If both stationing arguments
(station and station_int) are specified, all elements of
station have to be equal to
as.numeric(station_int / 1000).
Minimum and maximum allowed values of station are
river-specific: Elbe (km 0 - 585.7), Rhine (km 336.2 - 865.7).
an optional argument to hand over the stationing along the
specified river. If specified, it has to be type integer
and has to have the same length as other optional arguments (id,
station and w) forming the data.frame-component of a
WaterLevelDataFrame. If both stationing arguments (station
and station_int) are specified, all elements of station_int
have to be equal to as.integer(station * 1000).
Minimum and maximum allowed values of station_int are river-specific:
Elbe (m 0 - 585700), Rhine (m 336200 - 865700).
df.flys contains 1d water level data computed
with SOBEK for every second hectometer (every 200 m). This function
provides a way to interpolate the 30 stationary water levels for selected
stations inbetween these hectometers and returns them with the
data.frame-structure of the original dataset.
busch_einheitliche_2009hyd1d
hkv_hydrokontor_erstellung_2014hyd1d
deltares_sobek_2018hyd1d
df.flys
df.flys <- waterLevelFlys3InterpolateX("Elbe", 257.1)
Run the code above in your browser using DataLab